import setuptools


setuptools.setup(
    name="hiddenAlphabet",
    version="0.0.1",
    author="Mac Scheffer, Donaldo Celaj",
    author_email="author@example.com",
    description="Early testing.",
    long_description='long description',
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)